(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 2003 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* $Id: substitute.mli,v 1.8 2015/11/18 01:08:57 weis Exp $ *)

(** {3 Variable substitution in buffers} *)

type ident = string;;
type value = string;;

(** Occurrences of [$ident], [$(ident)], or [$(ident)] in a string are
   substituted according to an environment that maps variables to strings. *)

val add_string_substitute :
  (ident, value) Hashtbl.t -> Buffer.t -> string -> unit
(** [add_string_substitute t b s] Add string [s] to buffer [b], after
    substituting all occurrences of variables in [s].

    Regular variables are supposed to have the form [$ident], [$(ident)], or
    [${ident}].
    All regular variables found in [s] are substituted by their
    associated value in the hash table [t].

    System variables are supposed to have the form [$<ident>].
    All system variables found in [s] are substituted by their value in
    the user's environment (as given by the standard [Sys.getenv]
    function). *)
;;

val add_string : (ident -> value) -> Buffer.t -> string -> unit
(** Same as above with a general substitution function. *)
;;

val add_string_flush_substitute :
  (ident, value) Hashtbl.t -> Ufbuffer.t -> string -> unit
;;

val add_string_flush : (ident -> value) -> Ufbuffer.t -> string -> unit
(** Same as above with a general substitution function. *)
;;

val is_quoted_string : string -> bool
(** A predicate to detect string in normal form
    (i.e. character strings enclosed between quote chars, ['\'']). *)
;;

val is_forced_string : string -> bool
(** A predicate to detect backquoted expression
    (i.e. character strings enclosed between backquote chars, ['`']). *)
;;
