(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2009-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: options.mli,v 1.36 2017/05/31 16:38:15 fclement Exp $ *)

open Segmentation_types;;

(* Codomain implementation.*)

type codomain_implementation =
  | Tuple_Cod
  | Vector_Cod
;;

val get_codomain_implementation :
  unit -> codomain_implementation
;;

(* Dimension.*)

type dimension = int;;

val phase_dimension : Ucommand_option.phase_name;;
val get_dimension : unit -> dimension;;

(* Dimension management. *)

type dimension_management =
  | Vector
  | Best_component_only
  | Best_component_for_each
  | Combine_best_components
;;

val get_dimension_management : unit -> dimension_management;;

(* Cutting strategy. *)

type cutting_strategy =
  | Option_Best_in_a_family
  | Option_Overall_best

and number_of_cuts = int

and basic_cutting_families = basic_cutting_family list
;;

val get_cutting_strategy : unit -> cutting_strategy;;
val get_number_of_cuts : unit -> number_of_cuts;;
val get_basic_cutting_families : unit -> basic_cutting_families;;

(* Stopping criterion. *)

type max_iteration = int
and min_best_scalar_indicator = float
and min_scalar_relative_error = float
;;

val get_max_iteration : unit -> max_iteration;;
val get_min_best_scalar_indicator :
  unit -> min_best_scalar_indicator
;;
val get_min_scalar_relative_error :
  unit -> min_scalar_relative_error
;;

(* Program configuration. *)

type out_formatter =
  | Std_out
  | Std_err
  | Out_file of Ufilename.t
;;

val get_out_formatter : unit -> out_formatter;;

type report_allocated_memory = bool;;

val get_report_allocated_memory :
  unit -> report_allocated_memory
;;

type incremental_mode = bool;;

val get_incremental_mode : unit -> incremental_mode;;

type graphics_mode =
  | No_graphics
  | Minimal_graphics
  | Parameter_graphics
  | Compound_graphics
  | Full_graphics
;;

val get_graphics_mode : unit -> graphics_mode;;

type graphics_window_min_width = int
and graphics_window_min_height = int
and graphics_window_max_width = int
and graphics_window_max_height = int
;;

val get_graphics_window_min_width :
  unit -> graphics_window_min_width
;;
val get_graphics_window_min_height :
  unit -> graphics_window_min_height
;;
val get_graphics_window_max_width :
  unit -> graphics_window_max_width
;;
val get_graphics_window_max_height :
  unit -> graphics_window_max_height
;;

type graphics_gradient_threshold = int;;

val get_graphics_gradient_threshold :
  unit -> graphics_gradient_threshold
;;

(* Initial and final images. *)

type argument_initial_image = image
and argument_initial_image_width = width
and argument_initial_image_height = height
;;

val get_argument_initial_image : unit -> argument_initial_image;;
val get_argument_initial_image_width : unit -> argument_initial_image_width;;
val get_argument_initial_image_height : unit -> argument_initial_image_height;;

type final_image_filename = Ufilename.t;;

val get_final_image_filename : unit -> final_image_filename;;

(* Report/debug flags and error messages. *)

val printing_facilities : Udebug.printing_facilities;;
