(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

let rec printer_t pp_a ctx ppf = function
  | t ->
    (fun a_a_a ->
     Og_printer.printer_Array (Og_printer.printer_Array pp_a) ctx ppf a_a_a)
      (Umatrix_types.of_t
      t)

and printer_matrix pp_a ctx ppf = function
  | a_t -> printer_t pp_a ctx ppf a_t
;;

let rec printer_length ctx ppf = function
  | u_l -> Uarray_print.printer_length ctx ppf u_l

and printer_index ctx ppf = function
  | u_i -> Uarray_print.printer_index ctx ppf u_i

and printer_line_number ctx ppf = function | l -> printer_length ctx ppf l

and printer_column_number ctx ppf = function | l -> printer_length ctx ppf l

and printer_line_index ctx ppf = function | i -> printer_index ctx ppf i
;;

let printer_size ctx ppf = function
  | (l, c) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_line_number Og_precedence.Ck_tuple_item ppf l;
    Format.fprintf ppf "%,,@ ";
    printer_column_number Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

(* Defining top printers. *)

let print_t pp_a ppf = printer_t pp_a Og_precedence.Ck_toplevel ppf

and print_matrix pp_a ppf = printer_matrix pp_a Og_precedence.Ck_toplevel ppf
;;

let print_length ppf = printer_length Og_precedence.Ck_toplevel ppf

and print_index ppf = printer_index Og_precedence.Ck_toplevel ppf

and print_line_number ppf = printer_line_number Og_precedence.Ck_toplevel ppf

and print_column_number ppf =
  printer_column_number Og_precedence.Ck_toplevel ppf

and print_line_index ppf = printer_line_index Og_precedence.Ck_toplevel ppf
;;

let print_size ppf = printer_size Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
