(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

let printer_uindex pp_a ctx ppf = function
  | a_u_u -> Unonempty_set_print.printer_uindex pp_a ctx ppf a_u_u

and printer_index pp_a ctx ppf = function
  | a_u_i -> Unonempty_set_print.printer_index pp_a ctx ppf a_u_i
;;

let rec printer_t pp_a ctx ppf = function
  | Uset.Empty ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Empty"
  | Uset.Nonempty a_u_t ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Nonempty";
    Unonempty_set_print.printer_t pp_a Og_precedence.Ck_argument ppf a_u_t;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"

and printer_set pp_a ctx ppf = function | a_t -> printer_t pp_a ctx ppf a_t
;;

let printer_subset pp_a ctx ppf = function
  | { Uset.support = a_t; Uset.indices = a_i_a; Uset.set = a_t0; } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>support =";
    printer_t pp_a Og_precedence.Ck_record_field ppf a_t;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>indices =";
    Og_printer.printer_Array (printer_index pp_a)
      Og_precedence.Ck_record_field
      ppf
      a_i_a;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>set =";
    printer_t pp_a Og_precedence.Ck_record_field ppf a_t0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_dichotomy pp_a ctx ppf = function
  | (a_s, a_s0) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_subset pp_a Og_precedence.Ck_tuple_item ppf a_s;
    Format.fprintf ppf "%,,@ ";
    printer_subset pp_a Og_precedence.Ck_tuple_item ppf a_s0;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

(* Defining top printers. *)

let print_uindex pp_a ppf = printer_uindex pp_a Og_precedence.Ck_toplevel ppf

and print_index pp_a ppf = printer_index pp_a Og_precedence.Ck_toplevel ppf
;;

let print_t pp_a ppf = printer_t pp_a Og_precedence.Ck_toplevel ppf

and print_set pp_a ppf = printer_set pp_a Og_precedence.Ck_toplevel ppf
;;

let print_subset pp_a ppf = printer_subset pp_a Og_precedence.Ck_toplevel ppf
;;

let print_dichotomy pp_a ppf =
  printer_dichotomy pp_a Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
