(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: udynamic_graph.mli,v 1.14 2017/05/31 15:24:06 fclement Exp $ *)

(** {3 Dynamic graphs} *)

(** Direct access data structure. *)

type length = Ustamped_darray.length;;
type arrow_number = Ustamped_darray.index;;

type ('a, 'b) arrow = {
  value : 'a;
  image : 'b;
}
(** An [('a, 'b) arrow] represents a point in the graph of a function
 of type ['a -> 'b]. *)
;;

val get_value : ('a, 'b) arrow -> 'a;;

type ('a, 'b) t = ('a, 'b) arrow Ustamped_darray.t
and ('a, 'b) dynamic_graph = ('a, 'b) t
;;

val make : length -> ('a, 'b) t;;

val get : ('a, 'b) t -> arrow_number -> ('a, 'b) arrow;;

val next_unset : ('a, 'b) t -> arrow_number;;
val set_next : ('a, 'b) t -> ('a, 'b) arrow -> unit;;
val set : ('a, 'b) t -> arrow_number -> ('a, 'b) arrow -> unit;;

val same : ('a, 'b) t -> ('a, 'b) t -> bool;;
val equal_values : ('a -> 'a -> bool) -> ('a, 'b) t -> ('a, 'b) t -> bool;;

(** {6 Converters} *)

val to_array : ('a, 'b) t -> ('a, 'b) arrow array;;

val to_values : ('a, 'b) t -> 'a array;;
val of_values : ('a -> 'b) -> 'a array -> ('a, 'b) t;;

(** {6 Iterators} *)

val iter : (arrow_number -> ('a, 'b) arrow -> unit) -> ('a, 'b) t -> unit;;

val map :
  (arrow_number -> ('a, 'b) arrow -> ('c, 'd) arrow) ->
  ('a, 'b) t -> ('c, 'd) t
;;

val fold_left :
  ('accu -> arrow_number -> ('a, 'b) arrow -> 'accu) ->
  'accu -> ('a, 'b) t -> 'accu
;;
