(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: ugraph_types.ml,v 1.4 2017/05/31 15:24:06 fclement Exp $ *)

(* The private type of graphs of functions. *)

module Nat = Unatural;;
module A = Uarray;;
module M = Umatrix;;
module Nset = Unonempty_set;;

let _0_ = Nat._0_;;

let qual = Upervasives.qualify "Ugraph";;
let invalid_arg = Upervasives.invalid_arg_qual qual;;

type 'a index = 'a Nset.index
and 'a uindex = 'a Nset.uindex
;;

type 'a domain = 'a Nset.t;;

type 'b images =
  | Constant of 'b
  | Images of 'b array
;;

type ('a, 'b) t =
  {
   domain : 'a domain;
   images : 'b images;
  }
and ('a, 'b) graph = ('a, 'b) t
;;

let constant dom y = { domain = dom; images = Constant y; };;

let from_array dom ims =
  if Nset.cardinal dom <> A.length ims then
    invalid_arg "from_array" "arguments have different sizes" else
  { domain = dom; images = Images ims; }
;;

let from_fun dom f =
  let uindices = Nset.uindices dom in
  let y0 = f Uindex._0_ (A.get uindices _0_) in
  let constant = ref true in
  let ff i uindex =
    if i = _0_ then y0 else
    let y = f (Uindex.of_nat i) uindex in
    if not !constant then y else
    if y = y0 then y0 else begin constant := false; y end in
  let ims = A.map_i ff uindices in
  let images = if !constant then Constant y0 else Images ims in
  { domain = dom; images = images; }
;;

let of_matrix m =
  let (height, width) = M.size m in
  let dom =
    Nset.of_rectangle (Nat.to_int height) (Nat.to_int width) in
  let ims = M.to_array m in
  { domain = dom; images = Images ims; }
;;

let map_images f g =
  match g.images with
  | Constant y -> { g with images = Constant (f y); }
  | Images ims -> { g with images = Images (A.map f ims); }
;;
