(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: upositive_rational_range_types.ml,v 1.12 2017/05/31 15:24:06 fclement Exp $ *)

(* The private type of positive rational number ranges. *)

module Rat = Upositive_rational;;

let qual = Upervasives.qualify "Upositive_rational_range";;
let failwith = Upervasives.failwith_qual qual;;

type nonempty_range =
  {
   left : Rat.t;
   right : Rat.t;
  }
;;

let to_nonempty_range rl rr =
  if Rat.greater_or_equal rl rr then
    failwith "to_nonempty_range" "empty range" else
  { left = rl; right = rr; }
;;

type t =
  | Empty
  | Nonempty of nonempty_range
and positive_rational_range = t
;;
