(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: usubarray.mli,v 1.14 2017/05/31 15:24:06 fclement Exp $ *)

(** {3 Operations on subarrays} *)

type length = Usubarray_types.length
and index = Usubarray_types.index
and offset = Usubarray_types.offset
and range = Usubarray_types.range =
  {
   offset : offset;
   length : length;
  }
and indices = Usubarray_types.indices =
  | Range of range
  | Indices of index array
and 'a t = 'a Usubarray_types.t = private
  {
   support : 'a array;
   indices : indices;
  }
and 'a subarray = 'a t
;;

val range : 'a array -> range -> 'a t
(** [range sup rg] creates a subarray which elements are those of the support
 array [sup] with indices in the range
 [\[rg.offset, rg.offset + rg.length\[].

 Raise [invalid_arg] if [rg] is not a valid range of indices of [sup]. *)
;;

val indices : 'a array -> index array -> 'a t
(** [indices sup idxa] creates a subarray which elements are those of the
 support array [sup] with indices in the index array [idxa].

 Raise [Invalid_arg] if [ia] contains an invalid index. *)
;;

val fold_left : ('accu -> 'a -> 'accu) -> 'accu -> 'a t -> 'accu
(** [fold_left f x sa] computes
 [f (... (f (f x sup.(ofs)) sup.(ofs+1)) ...) sup.(ofs+len-1)], when the
 subarray [sa] is given by the range [\[ofs, ofs+len\[] in support [sup],
 and [f (... (f (f x sup.(ia.(0))) sup.(ia.(1))) ...) sup.(ia(n-1))], when
 the subarray [sa] is given by the index array [ia] where [n] is the length
 of [ia]. *)
;;

val fold_left_i :
  ('accu -> index -> index -> 'a -> 'accu) -> 'accu -> 'a t -> 'accu
(** Same as {!fold_left}, but the function is applied to the index of the
 element (in the subarray) as second argument, and to the index in the
 support array as third argument. *)
;;

val find : ('a -> bool) -> 'a t -> 'a
(** [find p sa] returns the first element of the subarray [sa] that satisfies
 the predicate [p] if any, otherwise raises [Not_found]. *)
;;

val find_all : ('a -> bool) -> 'a t -> 'a list
(** [find_all p sa] returns all the elements of the subarray [sa] that
 satisfies the predicat [p] if any (in reverse order), otherwise returns
 [[]]. *)
;;
